
"""pylintfileheader module"""

from __future__ import absolute_import
from pylintfileheader import plugin, file_header_checker  # noqa: F401


register = plugin.register # pylint: disable=invalid-name
